cgexplore.terms.TargetNonbonded
===============================

.. currentmodule:: cgexplore.terms

.. autoclass:: TargetNonbonded
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~TargetNonbonded.human_readable
      ~TargetNonbonded.vector
      ~TargetNonbonded.vector_key
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TargetNonbonded.bead_class
      ~TargetNonbonded.bead_element
      ~TargetNonbonded.sigma
      ~TargetNonbonded.epsilon
      ~TargetNonbonded.force
   
   